@echo off
REM ****************************************************** {COPYRIGHT-TOP} ***
REM Licensed Materials - Property of IBM
REM 5724-M07, 5698-A77
REM
REM (C) Copyright IBM Corp. 2006 All Rights Reserved.
REM
REM US Government Users Restricted Rights - Use, duplication, or
REM disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
REM ****************************************************** {COPYRIGHT-END} ***
REM ------------------------------------------------------------------------------
REM
REM DLA File Transfer
REM
REM ------------------------------------------------------------------------------

setlocal

REM ------------------------------------------------------------------------------
REM Set ftDebug to true for extra debug information
REM ------------------------------------------------------------------------------
set ftDebug=false

REM ------------------------------------------------------------------------------
REM Change to directory that the bat file is run from so that relative
REM Directories will work properly
REM ------------------------------------------------------------------------------
cd %~dp0

REM set the defaults first
set templateDir=..\templates
set dlaFtDir=..\jars
set javaHome=""
set javaHome_NO_QM=
set transferProtocol=FTP
set javaCmd=java

if "%1"=="" goto main

REM ------------------------------------------------------------------------------
REM Parse options:
REM    -c indicates that a confirm of the file transfer is be performed.
REM    -p specifies the file transfer protocol for the transfer. Default is FTP
REM    -t Specifies the directory containing the file transfer templates.
REM       default is: ..\templates
REM    -d Specifies the location of the File Transfer jars. Default is
REM       ..\jars
REM    -j Specifies the directory where the java executable can be found. If
REM       not specified, java command is used without specifying the location.
REM Anything else signifies an error
REM ------------------------------------------------------------------------------


:processArgs
if "%1"=="" goto main
if "%1"=="-c" goto processCOption
if "%1"=="-p" goto processPOption
if "%1"=="-t" goto processTOption
if "%1"=="-d" goto processDOption
if "%1"=="-j" goto processJOption

goto error2

:processCOption
set dlaConfirm=true
shift
goto processArgs

:processPOption
if "%2"=="" goto error2
set transferProtocol=%2
shift
shift
goto processArgs

:processTOption
if "%2"=="" goto error2
set templateDir=%2
shift
shift
goto processArgs

:processDOption
if "%2"=="" goto error2
set dlaFtDir=%2
shift
shift
goto processArgs

:processJOption
if "%~2"=="" goto error2
set javaHome=%2
set javaHome_NO_QM=%~2
set javaCmd="%javaHome_NO_QM%\%javaCmd%"
shift
shift
goto processArgs

goto main

REM ------------------------------------------------------------------------------
REM Main logic section
REM ------------------------------------------------------------------------------
:main
set transferProtocolScript=DLA_FileTransfer_%transferProtocol%.bat
set classpath=%classpath%;.;%dlaFtDir%\dla_file_transfer.jar;%dlaFtDir%\dl_core.jar;%dlaFtDir%\tesmagent.jar;%dlaFtDir%\com.ibm.management.soa.utils.jar;%dlaFtDir%\jlog.jar
%javaCmd% com.ibm.management.soa.dla.filetransfer.MessageLogger FILE_TRANSFER_STARTED INFO
set dlaStartedMsg=true

REM ------------------------------------------------------------------------------
REM Ensure that the protocol script exists
REM ------------------------------------------------------------------------------
if not exist %transferProtocolScript% goto error4

REM ------------------------------------------------------------------------------
REM Define the names of the properties to be read
REM ------------------------------------------------------------------------------
set dlaHostProp=com.ibm.management.soa.dla.filetransfer.host
set dlaConfirmProp=com.ibm.management.soa.dla.filetransfer.confirmTransfer
set dlaTargetDirProp=com.ibm.management.soa.dla.filetransfer.targetDir
set dlaStagingDirProp=com.ibm.management.soa.dla.filetransfer.stagingDir,WinDir
set dlaFileFilterProp=com.ibm.management.soa.dla.filetransfer.fileFilter
set dlaUseridProp=com.ibm.management.soa.dla.filetransfer.userid
set dlaPasswordProp=com.ibm.management.soa.dla.filetransfer.password
set dlaTempDirProp=com.ibm.management.soa.dla.filetransfer.log.logFileDir,WinDir
REM Special property to hold time stamp. Useful for holding files under
REM unique names in error scenarios.
set timeInMillis=_TIME

REM ------------------------------------------------------------------------------
REM Call Read Properties utility to get the values of the properties.  The
REM first parm passed to the utility is the name of the bat file to create which
REM will define the variables for us to use.  We will need to call the bat file
REM and then delete it.
REM
REM Values generated by utility are in format of: <name>_value where <name> is
REM is the last part of the property name. For instance a property of a.b.c
REM would have its value store in c_value. Note that the last part of the property
REM names must be unique.
REM ------------------------------------------------------------------------------
set dlaVarBatFile=tmpSetDLAVars.bat
%javaCmd% com.ibm.management.soa.dla.filetransfer.PropertyReader %dlaVarBatFile% %dlaHostProp% %dlaConfirmProp% %dlaTargetDirProp% %dlaStagingDirProp% %dlaFileFilterProp% %dlaUseridProp% %dlaPasswordProp% %timeInMillis% %dlaTempDirProp%
if errorlevel 1 goto error1

call %dlaVarBatFile%
erase %dlaVarBatFile%

REM - if confirm flag isn't set to true, use value from properties file
if not "%dlaConfirm%"=="true" set dlaConfirm=%confirmTransfer_value%

REM ------------------------------------------------------------------------------
REM Confirm that the staging directory exists
REM ------------------------------------------------------------------------------
if not exist %stagingDir_value% goto error3

REM ------------------------------------------------------------------------------
REM Get all files from directory that match the filter
REM ------------------------------------------------------------------------------
for %%f in (%stagingDir_value%\%filefilter_value%) do call %transferProtocolScript% %%f

goto end

REM ------------------------------------------------------------------------------
REM Error section
REM     error1 - error occured when reading properties
REM     error2 - syntax error
REM     error3 - staging directory does not exist
REM     error4 - protocol file not found
REM ------------------------------------------------------------------------------
:error1
if "%ftDebug%"=="true" echo Error occured while reading properties
goto end

:error2
set classpath=%classpath%;.;%dlaFtDir%\dla_file_transfer.jar;%dlaFtDir%\dl_core.jar;%dlaFtDir%\tesmagent.jar;%dlaFtDir%\com.ibm.management.soa.utils.jar;%dlaFtDir%\jlog.jar
%javaCmd% com.ibm.management.soa.dla.filetransfer.MessageLogger FILE_TRANSFER_SYNTAX_ERROR SYSOUT
goto end

:error3
if "%ftDebug%"=="true" echo Staging directory %stagingDir_value% not found.
%javaCmd% com.ibm.management.soa.dla.filetransfer.MessageLogger INVALID_DLFS_LOCATION ERROR %stagingDir_value%
goto end

:error4
if "%ftDebug%"=="true" echo Protocol script %transferProtocolScript% not found.
%javaCmd% com.ibm.management.soa.dla.filetransfer.MessageLogger PROTOCOL_NOT_SUPPORTED ERROR %transferProtocolScript% %transferProtocol%
goto end

REM ------------------------------------------------------------------------------
REM End script
REM ------------------------------------------------------------------------------
:end
if "%dlaStartedMsg%"=="true" %javaCmd% com.ibm.management.soa.dla.filetransfer.MessageLogger FILE_TRANSFER_ENDED INFO
if "%ftDebug%"=="true" echo "ending program"
endlocal
