#!/bin/sh
# ****************************************************** {COPYRIGHT-TOP} ***
# Licensed Materials - Property of IBM
# 5724-M07, 5698-A77
#
# (C) Copyright IBM Corp. 2006 All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ****************************************************** {COPYRIGHT-END} ***
# ------------------------------------------------------------------------------
#
# DLA File Transfer
#
# ------------------------------------------------------------------------------

# ------------------------------------------------------------------------------
# Set ftDebug to true for extra debug information
# ------------------------------------------------------------------------------
ftDebug=false

#  set the defaults first
templateDir=../templates
dlaFtDir=../jars
javaHome=
javaCmd=java
transferProtocol=FTP

# ------------------------------------------------------------------------------
# Log message
# ------------------------------------------------------------------------------
Log ()
{
  $javaCmd -cp $classpath com.ibm.management.soa.dla.filetransfer.MessageLogger $*
}

# ------------------------------------------------------------------------------
# Exit script and log ending message
# ------------------------------------------------------------------------------
ExitScript ()
{
  Log FILE_TRANSFER_ENDED INFO
  exit
}

# ------------------------------------------------------------------------------
# Display usage information
# ------------------------------------------------------------------------------
Usage ()
{
  classpath=$classpath:.:$dlaFtDir/dla_file_transfer.jar:$dlaFtDir/dl_core.jar:$dlaFtDir/tesmagent.jar:$dlaFtDir/com.ibm.management.soa.utils.jar:$dlaFtDir/jlog.jar
  Log FILE_TRANSFER_SYNTAX_ERROR SYSOUT
}


# ------------------------------------------------------------------------------
# Parse options:
#    -c indicates that a confirm of the file transfer is be performed.
#    -p specifies the file transfer protocol for the transfer. Default is FTP
#    -t Specifies the directory containing the file transfer templates.
#       default is: ..\templates
#    -d Specifies the location of the File Transfer jars. Default is
#       ..\jars
#    -j Specifies the directory where the java executable can be found. If
#       not specified, java command is used without specifying the location.
# Anything else signifies an error
# ------------------------------------------------------------------------------
while [ "$1" != "" ]
do
  if [ "$1" = "-c" ]
  then
    dlaConfirm="true"
    shift
  elif [ "$1" = "-p" ]
  then
    if [ "$2" != "" ]
    then
      transferProtocol="$2"
      shift 2
    else
      Usage
      shift
    fi
  elif [ "$1" = "-t" ]
  then
    if [ "$2" ]
    then
      templateDir="$2"
      shift 2
    else
      Usage
      exit
    fi
  elif [ "$1" = "-d" ]
  then
    if [ "$2" != "" ]
    then
      dlaFtDir="$2"
      shift 2
    else
      Usage
      exit
    fi
  elif [ "$1" = "-j" ]
  then
    if [ "$2" ]
    then
      javaHome="$2"
      javaCmd=$javaHome/$javaCmd
      shift 2
    else
      Usage
      exit
    fi
  else
    Usage
    exit
  fi
done

# ------------------------------------------------------------------------------
# Main logic section
# ------------------------------------------------------------------------------

transferProtocolScript=./DLA_FileTransfer_$transferProtocol.sh
classpath=$classpath:.:$dlaFtDir/dla_file_transfer.jar:$dlaFtDir/dl_core.jar:$dlaFtDir/tesmagent.jar:$dlaFtDir/com.ibm.management.soa.utils.jar:$dlaFtDir/jlog.jar
Log FILE_TRANSFER_STARTED INFO

# ------------------------------------------------------------------------------
# Ensure that the protocol script exists and that it is readable by the script
# ------------------------------------------------------------------------------
if [ ! -r $transferProtocolScript ]
then
  Log PROTOCOL_NOT_SUPPORTED ERROR $transferProtocolScript $transferProtocol
  exit
fi

# ----------------------------------------------------------------------------
# Define the names of the properties to be read
# ----------------------------------------------------------------------------
dlaHostProp=com.ibm.management.soa.dla.filetransfer.host
dlaConfirmProp=com.ibm.management.soa.dla.filetransfer.confirmTransfer
dlaTargetDirProp=com.ibm.management.soa.dla.filetransfer.targetDir
dlaStagingDirProp=com.ibm.management.soa.dla.filetransfer.stagingDir
dlaFileFilterProp=com.ibm.management.soa.dla.filetransfer.fileFilter
dlaUseridProp=com.ibm.management.soa.dla.filetransfer.userid
dlaPasswordProp=com.ibm.management.soa.dla.filetransfer.password
dlaTempDirProp=com.ibm.management.soa.dla.filetransfer.log.logFileDir
# Special property to hold time stamp. Useful for holding files under
# unique names in error scenarios.
timeInMillis=_TIME

# ------------------------------------------------------------------------------
# Call Read Properties utility to get the values of the properties.  The
# first parm passed to the utility is the name of the bat file to create which
# will define the variables for us to use.  We will need to call the bat file
# and then delete it.
#
# Values generated by utility are in format of: <name>_value where <name> is
# is the last part of the property name. For instance a property of a.b.c
# would have its value store in c_value. Note that the last part of the property
# names must be unique.
# ------------------------------------------------------------------------------
dlaVarScriptFile=./tmpSetDLAVars.sh
$javaCmd -cp $classpath com.ibm.management.soa.dla.filetransfer.PropertyReader $dlaVarScriptFile $dlaHostProp $dlaConfirmProp $dlaTargetDirProp $dlaStagingDirProp $dlaFileFilterProp $dlaUseridProp $dlaPasswordProp $timeInMillis $dlaTempDirProp

if [ $? -ne 0 ]
  then
    if [ "$ftDebug" = "true" ] ;then echo "Error occured while reading properties" ;fi
    ExitScript
  fi

chmod +x $dlaVarScriptFile
.  $dlaVarScriptFile
rm $dlaVarScriptFile

# - if confirm flag isn't set to true, use value from properties file
if [ "$dlaConfirm" != "true" ]
then
  dlaConfirm=$confirmTransfer_value
fi

# ------------------------------------------------------------------------------
# Confirm that the staging directory exists
# -----------------------------------------------------------------------------
if [ ! -d $stagingDir_value ]
then
  Log INVALID_DLFS_LOCATION ERROR $stagingDir_value
  ExitScript
fi

# ------------------------------------------------------------------------------
# Get all files from directory that match the filter
# ------------------------------------------------------------------------------
searchValue=$stagingDir_value/$fileFilter_value
for f in $searchValue
do
  if [ "$f" = "$searchValue" ]
  then
    if [ "$ftDebug" = "true" ] ;then echo "no files to transfer were found" ;fi
  else
    # If a transfer fails, do not ask to transfer any other files.
    if [ ! "$transferErrorOccured" = "true" ]
    then
      . $transferProtocolScript $f
    fi
  fi
done

ExitScript
