#!/bin/sh
# ****************************************************** {COPYRIGHT-TOP} ***
# Licensed Materials - Property of IBM
# 5724-M07, 5698-A77
#
# (C) Copyright IBM Corp. 2006 All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ****************************************************** {COPYRIGHT-END} ***
# ------------------------------------------------------------------------------
#
# FTP for sh script
#
# ------------------------------------------------------------------------------

# ------------------------------------------------------------------------------
# If an error occured during one of the file transfers for this run,
# then skip the remaining transfers
# ------------------------------------------------------------------------------
if [ "$transferErrorOccured" = "true" ]
then
  return
fi

fileToTransfer=$1
if [ "$fileToTransfer" = "" ]
then
  fileToTransfer=$f
fi

if [ "$ftDebug" = "true" ] ;then echo "FTP: transferring file $fileToTransfer" ;fi

ftpTempOutput=$logFileDir_value/tmpFtpOutput
rm $tmpFtpOutput 2> /dev/null

baseFileName=`basename $fileToTransfer`

# ------------------------------------------------------------------------------
# FTP will return a 0 even if the transfer failed. So we need to check
# for errors by looking at the transfer results.
# ------------------------------------------------------------------------------ 
CheckForFTPError ()
{
  $javaCmd -cp $classpath com.ibm.management.soa.dla.filetransfer.FTPOutputAnalyzer $1 $2 $3
  if [ $? -ne 0 ]
  then
    if [ "$ftDebug" = "true" ] ;then echo "FTP command failed" ;fi
    transferErrorOccured=true
  fi
}

# ------------------------------------------------------------------------------
# Handle a transfer without confirmation
# ------------------------------------------------------------------------------
NonConfirmedTransfer ()
{
  if [ "$ftDebug" = "true" ] ;then echo "Performing non-confirmed transfer" ;fi
  ftp -v -n $host_value <<END_FTP >$ftpTempOutput
    quote USER $userid_value
    quote PASS $password_value
    bin
    delete $targetDir_value/$baseFileName.partial
    put $fileToTransfer $targetDir_value/$baseFileName.partial
    rename $targetDir_value/$baseFileName.partial $targetDir_value/$baseFileName
    quit
END_FTP
  CheckForFTPError $ftpTempOutput 250
  if [ ! "$transferErrorOccured" = "true" ]
  then
    $javaCmd -cp $classpath com.ibm.management.soa.dla.filetransfer.MessageLogger TRANSFER_SUCCESSFUL INFO $fileToTransfer $host_value
    rm $fileToTransfer
    rm $ftpTempOutput
  else
   mv $ftpTempOutput $ftpTempOutput.$_TIME_value
   $javaCmd -cp $classpath com.ibm.management.soa.dla.filetransfer.MessageLogger FILE_TRANSFER_FAILED ERROR $ftpTempOutput.$_TIME_value
  fi  
}

# ------------------------------------------------------------------------------
# Confirmed transfer involves the following steps:
#    Step 1 - FTP file (but do not rename it yet) and download
#             the file that was just uploaded to a temp file.
#    Step 2 - Compare file being uploaded to the temp file.
#    Step 3 - If compare is good, use FTP to rename file on host. If it fails,
#             leave the partial file on host to aid in problem determination.
#             If the file is not deleted manually on the host, it will be 
#             deleted during the next DLA run.
# ------------------------------------------------------------------------------
ConfirmedTransfer ()
{
  # Step 1
  if [ "$ftDebug" = "true" ] ;then echo "Performing confirmed transfer" ;fi
  $javaCmd -cp $classpath com.ibm.management.soa.dla.filetransfer.MessageLogger CONFIRM_TRANSFER_STARTED INFO
  ftpTempDownloadFile=$logFileDir_value/tmpFtpDownloadFile
  rm $ftpTempDownloadFile 2> /dev/null
  ftp -v -n $host_value <<END_FTP >$ftpTempOutput
    quote USER $userid_value
    quote PASS $password_value
    bin
    delete $targetDir_value/$baseFileName.partial
    put $fileToTransfer $targetDir_value/$baseFileName.partial
    get $targetDir_value/$baseFileName.partial $ftpTempDownloadFile
    quit
END_FTP
  if [ "$ftDebug" = "true" ] ;then echo "checking for existence of $ftpTempDownloadFile" ;fi
  if [ ! -f $ftpTempDownloadFile ]
  then
    if [ "$ftDebug" = "true" ] ;then echo "FTP failed: file $ftpTempDownloadFile not found" ;fi 
    transferErrorOccured=true
    mv $ftpTempOutput $ftpTempOutput.$_TIME_value
    $javaCmd -cp $classpath com.ibm.management.soa.dla.filetransfer.MessageLogger FILE_TRANSFER_FAILED ERROR $ftpTempOutput.$_TIME_value
    return
  fi
  if [ "$ftDebug" = "true" ] ;then echo "comparing $ftpTempDownloadFile to $fileToTransfer" ;fi
  # Step 2: compare files to ensure they are equal
  cmp $ftpTempDownloadFile $fileToTransfer
  if [ $? -ne 0 ]
  then
    if [ "$ftDebug" = "true" ] ;then echo "FTP failed: files are not equal" ;fi
    $javaCmd -cp $classpath com.ibm.management.soa.dla.filetransfer.MessageLogger FILE_COMPARE_MISMATCH ERROR $fileToTransfer $host_value
    transferErrorOccured=true
    return
  fi
  rm $ftpTempDownloadFile 2> /dev/null
  $javaCmd -cp $classpath com.ibm.management.soa.dla.filetransfer.MessageLogger CONFIRM_SUCCESSFUL INFO $fileToTransfer
  # Step 3: rename file on host
  ftp -v -n $host_value <<END_FTP >$ftpTempOutput
    quote USER $userid_value
    quote PASS $password_value
    rename $targetDir_value/$baseFileName.partial $targetDir_value/$baseFileName
    quit
END_FTP
  CheckForFTPError $ftpTempOutput 250
  if [ ! "$transferErrorOccured" = "true" ]
  then
    $javaCmd -cp $classpath com.ibm.management.soa.dla.filetransfer.MessageLogger TRANSFER_SUCCESSFUL INFO $fileToTransfer $host_value
    rm $fileToTransfer
    rm $ftpTempOutput
  else
   mv $ftpTempOutput $ftpTempOutput.$_TIME_value
   $javaCmd -cp $classpath com.ibm.management.soa.dla.filetransfer.MessageLogger FILE_TRANSFER_RENAME_FAILED ERROR $fileToTransfer.partial $host_value
  fi
}

if [ "$dlaConfirm" = "true" ]
then
  ConfirmedTransfer
else
  NonConfirmedTransfer
fi
