#!/bin/sh
# ****************************************************** {COPYRIGHT-TOP} ***
# Licensed Materials - Property of IBM
# 5724-M07, 5698-A77, 5698-B16
#
# (C) Copyright IBM Corp. 2008 All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ****************************************************** {COPYRIGHT-END} ***
# ------------------------------------------------------------------------------
#
# WSRR DLA Process
#
# ------------------------------------------------------------------------------

# ------------------------------------------------------------------------------
# Set dladebug to true for extra debug information
# ------------------------------------------------------------------------------
dladebug=false

# ------------------------------------------------------------------------------
# Set the following variables to match your environment
#    WAS_BIN             - Set this to the WebSphere bin directory
#                          Example: /opt/IBM/WebSphere/AppServer/bin
#    WSRR_CLIENT_DIR     - Set this to the WSRR directory containing the
#                          ServiceRegistryClient.jar
#                          Example /opt/IBM/WebSphereServiceRegistry
# ------------------------------------------------------------------------------
WAS_BIN=
WSRR_CLIENT_DIR=

# ------------------------------------------------------------------------------
# Determine the directory the script is running from
# ------------------------------------------------------------------------------
RUN_DIR=`dirname $0`
cd $RUN_DIR
WSRR_DLA_RUN_DIR_FULL=`pwd`

WSRR_DLA_JAR_DIR=../jars
WSRR_DLA_EXT_DIR=../extdir

dlaConfirmOption=
runFileTransfer=true

ParseOptions () {
   # ------------------------------------------------------------------------------
   # Parse options:
   #    -c indicates that a confirm of the file transfer is be performed.
   #    -d run DLA only. Do not run file transfer script.
   #    -o Specifies the name of the DLA configuration properties file
   #    -r Force a refresh discovery.
   #    -p Specifies the protocol for file transfer
   # No errors are flagged by this function. The DLA program will handle
   # syntax errors.
   # ------------------------------------------------------------------------------
   while [ "$1" != "" ]
   do
     if [ "$1" = "-c" ]
     then
       dlaConfirmOption=-c
       shift
     elif [ "$1" = "-d" ]
     then
       runFileTransfer=false
       shift
     elif [ "$1" = "-o" ]
     then
       if [ "$2" != "" ]
       then
         shift 2
       else
         return
       fi
     elif [ "$1" = "-p" ]
     then
       if [ "$2" != "" ]
       then
         ftProtocol="$1 $2"
         shift 2
       else
         return
       fi
     elif [ "$1" = "-r" ]
     then
       shift
     else
       runFileTransfer=false
       shift
     fi
   done
}

ParseOptions $*

# ------------------------------------------------------------------------------
# Setup the WAS environment
# ------------------------------------------------------------------------------
TEMP_DIR=`dirname $WAS_BIN`
cd ${TEMP_DIR}
TEMP_DIR=`pwd`
REPLACE_WAS_HOME=$TEMP_DIR
cd $WAS_BIN
. ./setupCmdLine.sh > /dev/null
cd $WSRR_DLA_RUN_DIR_FULL

# ------------------------------------------------------------------------------
# Call the DLA
# ------------------------------------------------------------------------------
dla_classpath="$WAS_CLASSPATH":.:"$WSRR_DLA_JAR_DIR"/wsrr_dla.jar:"$WSRR_CLIENT_DIR"/ServiceRegistryClient.jar:"$WSRR_DLA_JAR_DIR"/dl_core.jar:"$WSRR_DLA_JAR_DIR"/idml_schema_2.4.jar:"$WSRR_DLA_JAR_DIR"/tesmagent.jar:"$WSRR_DLA_JAR_DIR"/com.ibm.management.soa.utils.jar:"$WSRR_DLA_JAR_DIR"/jlog.jar
# we can't use WAS_EXT_DIRS directly. It includes $WAS_HOME/lib/ext; that has classes that would get loaded with the extension classloader resulting in issues with loading classes with application class loader classpath
WAS_EXT_DIRS=$WAS_HOME/java/lib:$WAS_HOME/java/jre/lib/ext:$WAS_HOME/classes:$WAS_HOME/lib:$WAS_HOME/installedChannels:$WAS_HOME/web/help:$WAS_HOME/deploytool/itp/plugins/com.ibm.etools.ejbdeploy/runtime

if [ "$dladebug" = "true" ] ;then echo "Starting Dla..." ;fi
java $WAS_LOGGING -Djava.security.auth.login.config=file:"$USER_INSTALL_ROOT"/properties/wsjaas_client.conf -Djava.ext.dirs="$JAVA_HOME/jre/lib/ext:$WSRR_DLA_EXT_DIR:$WAS_EXT_DIRS:$WAS_HOME/plugins:$WAS_HOME/lib/WMQ/java/lib" -Djava.naming.factory.initial=com.ibm.websphere.naming.WsnInitialContextFactory -Dserver.root="$WAS_HOME" $CLIENTSAS $CLIENTSSL $USER_INSTALL_PROP -classpath "$dla_classpath" com.ibm.management.soa.dla.wsrr.WSRRDiscoveryLibraryAdapter $*

if [ $? -ne 0 ]
  then
    if [ "$dladebug" = "true" ] ;then echo "ERROR: DLA program encountered error. Check DLA logs for more information." ;fi
    exit
  fi

# ------------------------------------------------------------------------------
# Call the file transfer process unless the -d option was specified
# ------------------------------------------------------------------------------
if [ "$runFileTransfer" = "true" ]
  then
    if [ "$dladebug" = "true" ] ;then echo "Starting File Transfer Process..." ;fi
    ./DLA_FileTransfer.sh -j $JAVA_HOME/bin $dlaConfirmOption $ftProtocol
  fi
